@@ -48,18 +48,5 @@ int main() {
     }
   }
 
-  {
-    char* out = 0;
-    size_t out_length = 0;
-    unac_string("ISO-8859-1", "t", 3, &out, &out_length);
-    if(out_length != 3) {
-      fprintf(stderr, "out_length == %d instead of 3\n", out_length);
-      exit(1);
-    }
-    if(memcmp("ete", out, out_length)) {
-      fprintf(stderr, "out == %.*s instead of ete\n", out_length, out);
-      exit(1);
-    }
-  }
   return 0;
 }
